Module task_queue

Module task_queue 

Structs

DistributedTaskQueue
A distributed task queue. Executes tasks across 1 or more nodes, the behaviour of this implementation is at least once.
Initialize

Traits

Runnable
A task that can be run and return an output

Type Aliases

TaskId