Runnable

Trait Runnable 

pub trait Runnable<Event, State> {
    // Required methods
    fn id(&self) -> TaskId;
    fn run(&self, state: State) -> impl Future<Output = Result<Event>> + Send;
}
A task that can be run and return an output

Required Methods

fn id(&self) -> TaskId

a unique identifier for the task, should be unique across all tasks, nodes and plugins

fn run(&self, state: State) -> impl Future<Output = Result<Event>> + Send

run the task and return the output if this method is called multiple times, it should return the same output

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors